@@ -3,7 +3,7 @@ package Net::DNS::Domain;
 use strict;
 use warnings;
 
-our $VERSION = (qw$Id: Domain.pm 1816 2020-10-16 09:44:21Z willem $)[2];
+our $VERSION = (qw$Id: Domain.pm 1841 2021-06-23 20:34:28Z willem $)[2];
 
 
 =head1 NAME
@@ -26,8 +26,8 @@ Each domain object instance represents a single DNS domain which
 has a fixed identity throughout its lifetime.
 
 Internally, the primary representation is a (possibly empty) list
-of ASCII domain name labels, and optional link to an arbitrary
-origin domain object topologically closer to the DNS root.
+of ASCII domain name labels, and optional link to an origin domain
+object topologically closer to the DNS root.
 
 The computational expense of Unicode character-set conversion is
 partially mitigated by use of caches.
@@ -48,10 +48,9 @@ use constant UTF8 => scalar eval {	## not UTF-EBCDIC  [see Unicode TR#16 3.6]
 	Encode::encode_utf8( chr(182) ) eq pack( 'H*', 'C2B6' );
 };
 
-use constant LIBIDN2 => defined eval { require Net::LibIDN2 };
-use constant LIBIDN  => LIBIDN2 ? undef : defined eval { require Net::LibIDN };
-
+use constant LIBIDN2  => defined eval { require Net::LibIDN2 };
 use constant IDN2FLAG => LIBIDN2 ? &Net::LibIDN2::IDN2_NFC_INPUT + &Net::LibIDN2::IDN2_NONTRANSITIONAL : 0;
+use constant LIBIDN   => LIBIDN2 ? undef : defined eval { require Net::LibIDN };
 
 # perlcc: address of encoding objects must be determined at runtime
 my $ascii = ASCII ? Encode::find_encoding('ascii') : undef;	# Osborn's Law:
@@ -97,8 +96,8 @@ sub new {
 	my ( $class, $s ) = @_;
 	croak 'domain identifier undefined' unless defined $s;
 
-	my $k = join '', $s, $class, $ORIGIN || '';		# cache key
-	my $cache = $$cache1{$k} ||= $$cache2{$k};		# two layer cache
+	my $index = join '', $s, $class, $ORIGIN || '';		# cache key
+	my $cache = $$cache1{$index} ||= $$cache2{$index};	# two layer cache
 	return $cache if defined $cache;
 
 	( $cache1, $cache2, $limit ) = ( {}, $cache1, 500 ) unless $limit--;	# recycle cache
@@ -129,7 +128,7 @@ sub new {
 		croak qq(label too long in "$s") if length > 63;
 	}
 
-	$$cache1{$k} = $self;					# cache object reference
+	$$cache1{$index} = $self;				# cache object reference
 
 	return $self if $s =~ /\.$/;				# fully qualified name
 	$self->{origin} = $ORIGIN || return $self;		# dynamically scoped $ORIGIN
@@ -159,11 +158,12 @@ sub name {
 	return unless defined wantarray;
 
 	my @label = shift->_wire;
+	return $self->{name} = '.' unless scalar @label;
+
 	for (@label) {
 		s/([^\055\101-\132\141-\172\060-\071])/$escape{$1}/eg;
 	}
 
-	return $self->{name} = '.' unless scalar @label;
 	return $self->{name} = _decode_ascii( join chr(46), @label );
 }
 
@@ -225,7 +225,7 @@ sub label {
 	my @label = shift->_wire;
 	for (@label) {
 		s/([^\055\101-\132\141-\172\060-\071])/$escape{$1}/eg;
-		_decode_ascii($_)
+		_decode_ascii($_);
 	}
 	return @label;
 }
@@ -244,7 +244,7 @@ represented by the appropriate escape sequence.
 =cut
 
 sub string {
-	( my $name = &name ) =~ s/(["();@])/\\$1/;		# escape special char
+	my $name = &name;
 	return $name =~ /[.]$/ ? $name : $name . '.';		# append trailing dot
 }
 
@@ -271,7 +271,7 @@ sub origin {
 		my $constructor = shift;
 		local $ORIGIN = $domain;			# dynamically scoped $ORIGIN
 		&$constructor;
-			}
+	}
 }
 
 
@@ -306,19 +306,16 @@ sub _encode_utf8 {			## perl internal encoding to UTF8
 sub _wire {
 	my $self = shift;
 
-	my $label = $self->{label};
+	my $label  = $self->{label};
 	my $origin = $self->{origin};
 	return ( @$label, $origin ? $origin->_wire : () );
 }
 
 
 %escape = eval {			## precalculated ASCII escape table
-	my %table = (						# ASCII printable,	\. \\
-		( map { ( $_ => $_ ) } map { pack( 'C', $_ ) } ( 33 .. 126 ) ),
-		( map { pack( 'C', $_ ) => pack( 'C2', 92, $_ ) } ( 46, 92 ) ),
-		);
+	my %table = map { ( chr($_) => chr($_) ) } ( 0 .. 127 );
 
-	foreach my $n ( 0 .. 32, 127 .. 255 ) {			# \ddd
+	foreach my $n ( 0 .. 32, 34, 92, 127 .. 255 ) {		# \ddd
 		my $codepoint = sprintf( '%03u', $n );
 
 		# transliteration for non-ASCII character encodings
@@ -327,6 +324,10 @@ sub _wire {
 		$table{pack( 'C', $n )} = pack 'C a3', 92, $codepoint;
 	}
 
+	foreach my $n ( 40, 41, 46, 59 ) {			# character escape
+		$table{chr($n)} = pack( 'C2', 92, $n );
+	}
+
 	return %table;
 };
 
